@@ -1,7 +1,11 @@
 #include "TextSet.hpp"
 
 #include "glgui.hpp"
-
+#ifdef HAVE_FREETYPE
+#include "Viewpoint.hpp"
+#include "R.h"
+#include <map>
+#endif
 //////////////////////////////////////////////////////////////////////////////
 //
 // CLASS
@@ -12,8 +16,9 @@
 //   a separate length buffer holds string lengths in order
 //
 
-TextSet::TextSet(Material& in_material, int in_ntexts, char** in_texts, double *in_center, double in_adj,
-                 int in_ignoreExtent)
+TextSet::TextSet(Material& in_material, int in_ntexts, char** in_texts, double *in_center, 
+                 double in_adjx, double in_adjy,
+                 int in_ignoreExtent, FontArray& in_fonts)
  : Shape(in_material, in_ignoreExtent), textArray(in_ntexts, in_texts)
 {
   int i;
@@ -21,7 +26,8 @@ TextSet::TextSet(Material& in_material, int in_ntexts, char** in_texts, double *
   material.lit = false;
   material.colorPerVertex(false);
 
-  adj = in_adj;
+  adjx = in_adjx;
+  adjy = in_adjy;
 
   // init vertex array
 
@@ -35,33 +41,40 @@ TextSet::TextSet(Material& in_material, int in_ntexts, char** in_texts, double *
 
     boundingBox += vertexArray[i];
   }
-
+  fonts = in_fonts;
 }
 
 TextSet::~TextSet()
 {
 }
 
+void TextSet::render(RenderContext* renderContext) {
+  draw(renderContext);
+}
+
 void TextSet::draw(RenderContext* renderContext) {
 
   int cnt;
+  GLFont* font;
 
   material.beginUse(renderContext);
 
-  renderContext->font->enable();
-
   StringArrayIterator iter(&textArray);
-
   for( cnt = 0, iter.first(); !iter.isDone(); iter.next(), cnt++ ) {
     if (!vertexArray[cnt].missing()) {
+      GLboolean valid;
       material.useColor(cnt);
       glRasterPos3f( vertexArray[cnt].x, vertexArray[cnt].y, vertexArray[cnt].z );
-      String text = iter.getCurrent();
-      renderContext->font->draw( text.text, text.length, adj, renderContext->gl2psActive );
+      glGetBooleanv(GL_CURRENT_RASTER_POSITION_VALID, &valid);
+      if (valid) {
+        font = fonts[cnt % fonts.size()];
+        if (font) {
+          String text = iter.getCurrent();
+          font->draw( text.text, text.length, adjx, adjy, *renderContext );
+        }
+      }
     }
   }
-
   material.endUse(renderContext);
 }
 
-
